@@ -643,6 +643,14 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r.raise_for_status()
         return r.json()['id']
 
+    def delete_channel(self, channel_slug):
+        channel_id = self.get_channel(channel_slug)["id"]
+        url = "{}/smartfeed/channels/{}".format(self._base_url_askdata, channel_id)
+
+        r = requests.delete(url=url, headers=self._headers)
+        r.raise_for_status()
+        return r
+
     def execute_dataset_sync(self, dataset_slug):
 
         dataset_id = self.get_dataset_by_slug(self._slug, dataset_slug)
